symbols = ['EURUSD',
           'GBPUSD',
           'EURJPY']
        #    'USDJPY',
        #    'AUDUSD',
        #    'USDCHF',
        #    'GBPJPY',
        #    'USDCAD',
        #    'EURGBP',
        #    'EURCHF',
        #    'AUDJPY']
        #    'NZDUSD',
        #    'CHFJPY',
        #    'EURAUD',
        #    'CADJPY',
        #    'GBPAUD',
        #    'EURCAD',
        #    'AUDCAD',
        #    'GBPCAD',
        #    'AUDNZD',
        #    'NZDJPY',
        #    'USDNOK',
        #    'AUDCHF',
        #    'USDMXN',
        #    'GBPNZD',
        #    'EURNZD',
        #    'CADCHF',
        #    'USDSGD',
        #    'USDSEK',
        #    'NZDCAD',
        #    'EURSEK',
        #    'GBPSGD',
        #    'EURNOK',
        #    'EURHUF',
        #    'USDPLN',
        #    'USDDKK',
        #    'GBPNOK',
        #    'NZDCHF',
        #    'GBPCHF',
        #    'USDTRY',
        #    'EURTRY',
        #    'EURZAR',
        #    'SGDJPY',
        #    'USDHKD',
        #    'USDZAR',
        #    'EURMXN',
        #    'EURPLN',
        #    'NZDSGD',
        #    'USDHUF',
        #    'EURCZK',
        #    'USDCZK',
        #    'EURDKK',
        #    'USDCNH',
        #    'GBPSEK']
